Learn R Programming

ramidst (version 0.1.0)

generate_stream_from_dbn: Generates a stream from a DBN. The DBN is assumed to be a classifier, and therefore there is a class variable.

Description

Generates a stream from a DBN. The DBN is assumed to be a classifier, and therefore there is a class variable.

Usage

generate_stream_from_dbn(net, sequences, seq_length, class_var)

Arguments

net
the network that will be sampled
sequences
the number of random sequences to generate. Each one will be an element of the stream.
seq_length
the length of the sequences
class_var
the class variable

Value

a Java object of class DataStream with the generated sequences