Learn R Programming

ramidst (version 0.1.0)

mpe_inference_from_stream: Runs MPE inference from an AMIDST data stream

Description

Runs MPE inference from an AMIDST data stream

Usage

mpe_inference_from_stream(network, evidence_variables, input_stream, parallel = T, seed = 3L)

Arguments

network
a java object of class BayesianNetwork over which the computations will be carried out
evidence_variables
a vector with the names of the observed variables
input_stream
and AMIDST data stream
parallel
a boolean indicating whether or not the items in the sample will be generated in parallel (when allowed by the system)
seed
the seed for the genertion of random numbers

Value

a data.frame with the MPE configuration for each item in the stream

References

D. Ramos-Lopez, A. Salmeron, R. Rumi, A.M. Martinez, T.D. Nielsen, A.R. Masegosa, H. Langseth, A.L. Madsen (2016) Scalable MAP inference in Bayesian networks based on a Map-Reduce approach. PGM'2016. JMLR: Workshop and Conference Proceedings, vol. 52: 415-425.

Examples

Run this code
## Not run: 
# network <- load_amidst_bn(system.file("extdata","WasteIncinerator.bn",
# package="ramidst"))
# sample_stream <- amidst_data_stream(system.file("extdata",
# "WasteIncineratorSample.arff",package="ramidst"))
# mpe_configurations <- mpe_inference_from_stream(network,c("E"),sample_stream)
# mpe_configurations
# ## End(Not run)

Run the code above in your browser using DataLab